from django.apps import AppConfig


class LabelsConfig(AppConfig):
    name = "apis_core.apis_labels"
